package jp.co.sds_corp.fxchart.graph;

import java.math.BigDecimal;
import java.text.ParseException;
import java.util.Map;

import jp.co.sds_corp.fxutil.CcyPair;
import jp.co.sds_corp.util.common.CmnDate;
import jp.co.sds_corp.util.common.CmnString;

/**
* 日足データを読み込むIRateSourceの実装です。
*/
public class DayFileSource extends RateFileSource
{
	public DayFileSource( CcyPair pair, String term, String span ) {
		super( pair, term, span );
	}

	public Map<String,RateHistRosoku> getData( CmnDate fr, CmnDate to, String span )
		throws Exception
	{
		if ( span.equals( "DAY" )) {
			return super.getData( fr, to );
		}
		return super.getData( fr, to, span );
	}

	public String getFileName( CmnDate date ) {
		String ret = dir + "/" + "rate.day";
		return ret;
	}

	protected RateHistRosoku parseRate( String line ) throws ParseException {
		CmnDate dt;
		BigDecimal	rate;

		String[] tok = CmnString.getStringToken( line, "\t" );
		if( !tok[0].equals( pair.getCcy1().getCode() ) ||
			!tok[1].equals( pair.getCcy2().getCode() ) ||
			!tok[2].equals( term ))
		{
			return null;
		}

		RateHistRosoku hist = new RateHistRosoku();
		dt = new CmnDate( tok[7], "yyyyMMdd" );
		hist.setStartDate( dt );
		hist.setEndDate( dt );
		rate = new BigDecimal( tok[3] )
						.setScale( pair.getPoint(), BigDecimal.ROUND_DOWN );
		hist.setHigh( rate );
		rate = new BigDecimal( tok[4] )
						.setScale( pair.getPoint(), BigDecimal.ROUND_DOWN );
		hist.setLow( rate );
		rate = new BigDecimal( tok[5] )
						.setScale( pair.getPoint(), BigDecimal.ROUND_DOWN );
		hist.setStart( rate );
		rate = new BigDecimal( tok[6] )
						.setScale( pair.getPoint(), BigDecimal.ROUND_DOWN );
		hist.setEnd( rate );
		return hist;
	}

	protected String getRateKey( RateHistRosoku rate ) {
		String key = rate.getStartDate().format( "yyyyMMdd" );
		return key;
	}

	protected String getHistoryKey( String span, RateHistRosoku rate ) {
		return null;
	}

	protected CmnDate getNextDate( CmnDate fr, CmnDate to, CmnDate dt ) {
		return null;
	}
}
